@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-class Pluggaloid::Filter
+class Pluggaloid::Filter < Pluggaloid::Handler
   # フィルタ内部で使う。フィルタの実行をキャンセルする。Plugin#filtering はfalseを返し、
   # イベントのフィルタの場合は、そのイベントの実行自体をキャンセルする。
   # また、 _result_ が渡された場合、Event#filtering の戻り値は _result_ になる。
@@ -9,10 +9,12 @@ class Pluggaloid::Filter
 
   # ==== Args
   # [event] 監視するEventのインスタンス
+  # [name:] 名前(String | nil)
+  # [slug:] フィルタスラッグ(Symbol | nil)
+  # [tags:] Pluggaloid::HandlerTag|Array フィルタのタグ
   # [&callback] コールバック
-  def initialize(event, &callback)
-    raise Pluggaloid::TypeError, "Argument `event' must be instance of Pluggaloid::Event, but given #{event.class}." unless event.is_a? Pluggaloid::Event
-    @event = event
+  def initialize(event, **kwrest, &callback)
+    super
     @callback = Proc.new
     event.add_filter self end
 
