@@ -1,16 +1,20 @@
 # -*- coding: utf-8 -*-
+require 'securerandom'
+require 'set'
 
-class Pluggaloid::Listener
+class Pluggaloid::Listener < Pluggaloid::Handler
   # プラグインコールバックをこれ以上実行しない。
   def self.cancel!
     throw :plugin_exit, false end
 
   # ==== Args
   # [event] 監視するEventのインスタンス
+  # [name:] 名前(String | nil)
+  # [slug:] イベントリスナスラッグ(Symbol | nil)
+  # [tags:] Pluggaloid::HandlerTag|Array リスナのタグ
   # [&callback] コールバック
-  def initialize(event, &callback)
-    raise Pluggaloid::TypeError, "Argument `event' must be instance of Pluggaloid::Event, but given #{event.class}." unless event.is_a? Pluggaloid::Event
-    @event = event
+  def initialize(event, **kwrest, &callback)
+    super
     @callback = Proc.new
     event.add_listener(self) end
 
